@@ -2,6 +2,6 @@ try:
     from sqlalchemy import create_engine
 except:
     from os import system
-    system("pip install SQLAlchemy")
+    system("pip install SQLAlchemy==1.4.46")
 
 from .pylocalstorage import LocalStorage, WriteStorageError
