@@ -19,6 +19,7 @@ class TestLocalStorage:
         (
             ("x", "this"),
             ("x", "localhost"),
+            ("x", {"name": "Brazil", "population": 215e6}),
         ),
     )
     def test_setItem(self, key, value):
@@ -38,12 +39,6 @@ class TestLocalStorage:
         else:
             assert True
 
-    def test_saveDict(self):
-        storage = LocalStorage()
-        address = {"country": "Brazil", "population": 215e6}
-        storage.setItem("address", address)
-        assert storage.getItem("address") == address
-
     def test_removeItem(self):
         storage = LocalStorage()
         storage.setItem("x", "this")
